Struct pallet_proxy::Module [−][src]
Implementations
impl<T: Config + 'static> Module<T>[src]
pub fn proxies<K: EncodeLike<T::AccountId>>(
key: K
) -> (Vec<ProxyDefinition<T::AccountId, T::ProxyType, T::BlockNumber>>, <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance)[src]
key: K
) -> (Vec<ProxyDefinition<T::AccountId, T::ProxyType, T::BlockNumber>>, <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance)
The set of account proxies. Maps the account which has delegated to the accounts which are being delegated to, together with the amount held on deposit.
pub fn announcements<K: EncodeLike<T::AccountId>>(
key: K
) -> (Vec<Announcement<T::AccountId, <<T as Config>::CallHasher as Hash>::Output, T::BlockNumber>>, <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance)[src]
key: K
) -> (Vec<Announcement<T::AccountId, <<T as Config>::CallHasher as Hash>::Output, T::BlockNumber>>, <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance)
The announcements made by the proxy (key).
impl<T: Config> Module<T>[src]
pub fn anonymous_account(
who: &T::AccountId,
proxy_type: &T::ProxyType,
index: u16,
maybe_when: Option<(T::BlockNumber, u32)>
) -> T::AccountId[src]
who: &T::AccountId,
proxy_type: &T::ProxyType,
index: u16,
maybe_when: Option<(T::BlockNumber, u32)>
) -> T::AccountId
Calculate the address of an anonymous account.
who: The spawner account.proxy_type: The type of the proxy that the sender will be registered as over the new account. This will almost always be the most permissiveProxyTypepossible to allow for maximum flexibility.index: A disambiguation index, in case this is called multiple times in the same transaction (e.g. withutility::batch). Unless you're usingbatchyou probably just want to use0.maybe_when: The block height and extrinsic index of when the anonymous account was created. None to use current block height and extrinsic index.
pub fn add_proxy_delegate(
delegator: &T::AccountId,
delegatee: T::AccountId,
proxy_type: T::ProxyType,
delay: T::BlockNumber
) -> DispatchResult[src]
delegator: &T::AccountId,
delegatee: T::AccountId,
proxy_type: T::ProxyType,
delay: T::BlockNumber
) -> DispatchResult
Register a proxy account for the delegator that is able to make calls on its behalf.
Parameters:
delegator: The delegator account.delegatee: The account that thedelegatorwould like to make a proxy.proxy_type: The permissions allowed for this proxy account.delay: The announcement period required of the initial proxy. Will generally be zero.
pub fn remove_proxy_delegate(
delegator: &T::AccountId,
delegatee: T::AccountId,
proxy_type: T::ProxyType,
delay: T::BlockNumber
) -> DispatchResult[src]
delegator: &T::AccountId,
delegatee: T::AccountId,
proxy_type: T::ProxyType,
delay: T::BlockNumber
) -> DispatchResult
Unregister a proxy account for the delegator.
Parameters:
delegator: The delegator account.delegatee: The account that thedelegatorwould like to make a proxy.proxy_type: The permissions allowed for this proxy account.delay: The announcement period required of the initial proxy. Will generally be zero.
pub fn deposit(
num_proxies: u32
) -> <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance[src]
num_proxies: u32
) -> <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance