Struct pallet_proxy::ProxyDefinition [−][src]
pub struct ProxyDefinition<AccountId, ProxyType, BlockNumber> {
pub delegate: AccountId,
pub proxy_type: ProxyType,
pub delay: BlockNumber,
}Expand description
The parameters under which a particular account has a proxy relationship with some other account.
Fields
delegate: AccountIdThe account which may act on behalf of another.
proxy_type: ProxyTypeA value defining the subset of calls that it is allowed to make.
delay: BlockNumberThe number of blocks that an announcement must be in place for before the corresponding call may be dispatched. If zero, then no announcement is needed.