Trait pallet_proxy::Config [−][src]
Configuration trait.
Associated Types
type Event: From<Event<Self>> + Into<Self::Event>[src]
The overarching event type.
type Call: Parameter + Dispatchable<Origin = Self::Origin, PostInfo = PostDispatchInfo> + GetDispatchInfo + From<Call<Self>> + IsSubType<Call<Self>> + IsType<Self::Call>[src]
The overarching call type.
type Currency: ReservableCurrency<Self::AccountId>[src]
The currency mechanism.
type ProxyType: Parameter + Member + Ord + PartialOrd + InstanceFilter<Self::Call> + Default[src]
A kind of proxy; specified with the proxy and passed in to the IsProxyable fitler.
The instance filter determines whether a given call may be proxied under this type.
IMPORTANT: Default must be provided and MUST BE the the most permissive value.
type ProxyDepositBase: Get<<Self::Currency as Currency<Self::AccountId>>::Balance>[src]
The base amount of currency needed to reserve for creating a proxy.
This is held for an additional storage item whose value size is
sizeof(Balance) bytes and whose key size is sizeof(AccountId) bytes.
type ProxyDepositFactor: Get<<Self::Currency as Currency<Self::AccountId>>::Balance>[src]
The amount of currency needed per proxy added.
This is held for adding 32 bytes plus an instance of ProxyType more into a pre-existing
storage value.
type MaxProxies: Get<u16>[src]
The maximum amount of proxies allowed for a single account.
type WeightInfo: WeightInfo[src]
Weight information for extrinsics in this pallet.
type MaxPending: Get<u32>[src]
The maximum amount of time-delayed announcements that are allowed to be pending.
type CallHasher: Hash[src]
The type of hash used for hashing the call.
type AnnouncementDepositBase: Get<<Self::Currency as Currency<Self::AccountId>>::Balance>[src]
The base amount of currency needed to reserve for creating an announcement.
This is held when a new storage item holding a Balance is created (typically 16 bytes).
type AnnouncementDepositFactor: Get<<Self::Currency as Currency<Self::AccountId>>::Balance>[src]
The amount of currency needed per announcement made.
This is held for adding an AccountId, Hash and BlockNumber (typically 68 bytes)
into a pre-existing storage value.